@@ -662,6 +662,33 @@ static BOOL xyzsh_seek_external_programs(char* path, sObject* sys, char* sname,
     if(dir) {
         struct dirent* entry;
         while(entry = readdir(dir)) {
+#if defined(__CYGWIN__)
+            char entry2[PATH_MAX];
+            if(strstr(entry->d_name, ".exe") == entry->d_name + strlen(entry->d_name) - 4) {
+                strcpy(entry2, entry->d_name);
+
+                entry2[strlen(entry2)-4] = 0;
+            }
+            else {
+                strcpy(entry2, entry->d_name);
+            }
+
+            char path2[PATH_MAX];
+            snprintf(path2, PATH_MAX, "%s/%s", path, entry2);
+
+            struct stat stat_;
+            memset(&stat_, 0, sizeof(struct stat));
+            stat(path2, &stat_);
+
+            if(strcmp(entry2, ".") != 0
+                && strcmp(entry2, "..") != 0
+                &&
+                (stat_.st_mode & S_IXUSR ||stat_.st_mode & S_IXGRP||stat_.st_mode & S_IXOTH)
+                && uobject_item(sys, entry2) == NULL)
+            {
+                uobject_put(sys, entry2, EXTPROG_NEW_GC(path2, TRUE));
+            }
+#else
             char path2[PATH_MAX];
             snprintf(path2, PATH_MAX, "%s/%s", path, entry->d_name);
             
@@ -677,6 +704,7 @@ static BOOL xyzsh_seek_external_programs(char* path, sObject* sys, char* sname,
             {
                 uobject_put(sys, entry->d_name, EXTPROG_NEW_GC(path2, TRUE));
             }
+#endif
         }
 
         closedir(dir);
