@@ -842,8 +842,8 @@ BOOL cmd_migemo_match(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             runinfo->mRCode = 0;
             if(!quiet) {
                 char buf[1024];
-                snprintf(buf, 1024, "0%d\n", (int)strlen(target));
-                if(!fd_write(nextout, buf)) {
+                int n = snprintf(buf, 1024, "0%d\n", (int)strlen(target));
+                if(!fd_write(nextout, buf, n)) {
                     err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
@@ -897,8 +897,8 @@ BOOL cmd_migemo_match(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 runinfo->mRCode = 0;
                 if(!quiet) {
                     char buf[1024];
-                    snprintf(buf, 1024, "%d\n%d\n", region->beg[0], region->end[0]);
-                    if(!fd_write(nextout, buf)) {
+                    int n = snprintf(buf, 1024, "%d\n%d\n", region->beg[0], region->end[0]);
+                    if(!fd_write(nextout, buf, n)) {
                         err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         onig_region_free(region, 1);
@@ -910,8 +910,8 @@ BOOL cmd_migemo_match(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             else {
                 if(!quiet) {
                     char buf[1024];
-                    snprintf(buf, 1024, "-1\n-1\n");
-                    if(!fd_write(nextout, buf)) {
+                    int n = snprintf(buf, 1024, "-1\n-1\n");
+                    if(!fd_write(nextout, buf, n)) {
                         err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         onig_region_free(region, 1);
