@@ -625,7 +625,7 @@ typedef struct {
     struct stat mStat;
 } sFile;
 
-sFile* sFile_new(char* name, struct stat* stat_)
+static sFile* sFile_new(char* name, struct stat* stat_)
 {
     sFile* self = MALLOC(sizeof(sFile));
 
@@ -635,7 +635,7 @@ sFile* sFile_new(char* name, struct stat* stat_)
     return self;
 }
 
-void sFile_delete(sFile* self)
+static void sFile_delete(sFile* self)
 {
     FREE(self);
 }
