@@ -248,7 +248,7 @@ BOOL cmd_cd(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
 BOOL cmd_popd(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
-    if(vector_size(gDirStack) > 0) {
+    if(vector_count(gDirStack) > 0) {
         sObject* pwd = vector_pop_back(gDirStack);
 
         if(pwd) {
