@@ -1420,6 +1420,18 @@ BOOL run(sObject* block, sObject* pipein, sObject* pipeout, int* rcode, sObject*
 {
     static int nest_level = 0;
     nest_level++;
+    if(nest_level == 50) {
+        if(SBLOCK(block).mStatmentsNum > 0) {
+            sStatment* statment = SBLOCK(block).mStatments + 0;
+            err_msg("stack over flow", statment->mFName, statment->mLine, "system");
+        }
+        else {
+            err_msg("stack over flow", "xyzsh", 0, "system");
+        }
+        nest_level--;
+        return FALSE;
+    }
+
     stack_start_stack();
 
     sRunInfo runinfo;
